@@ -928,9 +928,14 @@ static int execute_value_filter(ingest_info *info, harp_program *program)
         num_operations++;
     }
 
-    if (variable_def->unit != NULL)
+    for (k = 0; k < num_operations; k++)
     {
-        for (k = 0; k < num_operations; k++)
+        if (harp_operation_set_valid_range(program->operation[program->current_index + k], variable_def->data_type,
+                                           variable_def->valid_min, variable_def->valid_max) != 0)
+        {
+            return -1;
+        }
+        if (variable_def->unit != NULL)
         {
             if (harp_operation_set_value_unit(program->operation[program->current_index + k], variable_def->unit) != 0)
             {
@@ -1230,6 +1235,65 @@ static int execute_value_filter(ingest_info *info, harp_program *program)
     return 0;
 }
 
+static int execute_index_filter(ingest_info *info, harp_program *program)
+{
+    harp_operation_index_filter *operation;
+    harp_dimension_mask *dimension_mask;
+    long dimension;
+    long i, index;
+
+    if (info->product_mask == 0)
+    {
+        return 0;
+    }
+
+    operation = (harp_operation_index_filter *)program->operation[program->current_index];
+    dimension = info->dimension[operation->dimension_type];
+    if (dimension <= 0)
+    {
+        return 0;
+    }
+
+    if (info->dimension_mask_set[operation->dimension_type] == NULL)
+    {
+        if (harp_dimension_mask_new(1, &dimension, &info->dimension_mask_set[operation->dimension_type]) != 0)
+        {
+            return -1;
+        }
+    }
+
+    dimension_mask = info->dimension_mask_set[operation->dimension_type];
+
+    /* we only filter on the elements in the dimension that are still included */
+    index = 0;
+    for (i = 0; i < dimension; i++)
+    {
+        if (dimension_mask->mask[i])
+        {
+            int result;
+
+            result = operation->eval(operation, index);
+            if (result < 0)
+            {
+                return -1;
+            }
+            dimension_mask->mask[i] = result;
+            if (!dimension_mask->mask[i])
+            {
+                dimension_mask->masked_dimension_length--;
+            }
+            index++;
+        }
+    }
+
+    if (dimension_mask_set_has_empty_masks(info->dimension_mask_set))
+    {
+        info->product_mask = 0;
+    }
+
+    return 0;
+}
+
 static int execute_point_filter(ingest_info *info, harp_program *program)
 {
     harp_variable_definition *latitude_def;
@@ -1666,6 +1730,13 @@ static int evaluate_ingestion_mask(ingest_info *info, harp_program *program)
                     return -1;
                 }
                 break;
+            case operation_index_comparison_filter:
+            case operation_index_membership_filter:
+                if (execute_index_filter(info, program) != 0)
+                {
+                    return -1;
+                }
+                break;
             case operation_point_distance_filter:
             case operation_point_in_area_filter:
                 if (execute_point_filter(info, program) != 0)
@@ -2042,39 +2113,50 @@ static int ingest_metadata(const char *filename, const harp_ingestion_options *o
         return 0;
     }
 
-    /* read all (available) variables whose name starts with 'datetime' */
-    for (i = 0; i < info->product_definition->num_variable_definitions; i++)
+    if (info->product_definition->read_datetime_range != NULL)
     {
-        if (info->variable_mask[i])
+        if (info->product_definition->read_datetime_range(info->user_data, datetime_start, datetime_stop) != 0)
         {
-            harp_variable_definition *variable_def;
-            harp_variable *variable;
-
-            variable_def = info->product_definition->variable_definition[i];
-            if (strncmp(variable_def->name, "datetime", 8) != 0)
-            {
-                continue;
-            }
-
-            if (get_variable(info, variable_def, info->dimension_mask_set, &variable) != 0)
-            {
-                ingestion_done(info);
-                return -1;
-            }
-
-            if (harp_product_add_variable(info->product, variable) != 0)
-            {
-                harp_variable_delete(variable);
-                ingestion_done(info);
-                return -1;
-            }
+            ingestion_done(info);
+            return -1;
         }
     }
-
-    if (harp_product_get_datetime_range(info->product, datetime_start, datetime_stop) != 0)
+    else
     {
-        ingestion_done(info);
-        return -1;
+        /* read all (available) variables whose name starts with 'datetime' */
+        for (i = 0; i < info->product_definition->num_variable_definitions; i++)
+        {
+            if (info->variable_mask[i])
+            {
+                harp_variable_definition *variable_def;
+                harp_variable *variable;
+
+                variable_def = info->product_definition->variable_definition[i];
+                if (strncmp(variable_def->name, "datetime", 8) != 0)
+                {
+                    continue;
+                }
+
+                if (get_variable(info, variable_def, info->dimension_mask_set, &variable) != 0)
+                {
+                    ingestion_done(info);
+                    return -1;
+                }
+
+                if (harp_product_add_variable(info->product, variable) != 0)
+                {
+                    harp_variable_delete(variable);
+                    ingestion_done(info);
+                    return -1;
+                }
+            }
+        }
+
+        if (harp_product_get_datetime_range(info->product, datetime_start, datetime_stop) != 0)
+        {
+            ingestion_done(info);
+            return -1;
+        }
     }
 
     ingestion_done(info);
