@@ -257,9 +257,9 @@ double harp_fraction_of_year_from_datetime(double datetime);
 
 double harp_frequency_from_wavelength(double wavelength);
 double harp_frequency_from_wavenumber(double wavenumber);
-double harp_gravity_at_surface_from_latitude(double latitude);
-double harp_gravity_from_latitude_and_height(double latitude, double height);
+double harp_gravity_from_latitude_and_altitude(double latitude, double altitude);
 double harp_local_curvature_radius_at_surface_from_latitude(double latitude);
+double harp_normal_gravity_from_latitude(double latitude);
 double harp_normalized_radiance_from_radiance_and_solar_irradiance(double radiance, double solar_irradiance);
 double harp_normalized_radiance_from_reflectance_and_solar_zenith_angle(double reflectance, double solar_zenith_angle);
 
