@@ -158,9 +158,14 @@ static int execute_value_filter(harp_product *product, harp_program *program)
     }
     data_type_size = harp_get_size_for_type(variable->data_type);
 
-    if (variable->unit != NULL)
+    for (k = 0; k < num_operations; k++)
     {
-        for (k = 0; k < num_operations; k++)
+        if (harp_operation_set_valid_range(program->operation[program->current_index + k], variable->data_type,
+                                           variable->valid_min, variable->valid_max) != 0)
+        {
+            return -1;
+        }
+        if (variable->unit != NULL)
         {
             if (harp_operation_set_value_unit(program->operation[program->current_index + k], variable->unit) != 0)
             {
@@ -213,6 +218,7 @@ static int execute_value_filter(harp_product *product, harp_program *program)
 
         if (harp_dimension_mask_new(variable->num_dimensions, variable->dimension, &dimension_mask) != 0)
         {
+            harp_dimension_mask_set_delete(dimension_mask_set);
             return -1;
         }
         dimension_mask_set[variable->dimension_type[0]] = dimension_mask;
@@ -372,6 +378,65 @@ static int execute_value_filter(harp_product *product, harp_program *program)
     return 0;
 }
 
+static int execute_index_filter(harp_product *product, harp_program *program)
+{
+    harp_dimension_mask_set *dimension_mask_set = NULL;
+    harp_operation_index_filter *operation;
+    harp_dimension_mask *dimension_mask;
+    long dimension;
+    long i;
+
+    if (harp_dimension_mask_set_new(&dimension_mask_set) != 0)
+    {
+        return -1;
+    }
+
+    operation = (harp_operation_index_filter *)program->operation[program->current_index];
+    dimension = product->dimension[operation->dimension_type];
+    if (dimension <= 0)
+    {
+        return 0;
+    }
+
+    if (harp_dimension_mask_set_new(&dimension_mask_set) != 0)
+    {
+        return -1;
+    }
+    if (harp_dimension_mask_new(1, &dimension, &dimension_mask) != 0)
+    {
+        harp_dimension_mask_set_delete(dimension_mask_set);
+        return -1;
+    }
+    dimension_mask_set[operation->dimension_type] = dimension_mask;
+
+    for (i = 0; i < dimension; i++)
+    {
+        int result;
+
+        result = operation->eval(operation, i);
+        if (result < 0)
+        {
+            harp_dimension_mask_set_delete(dimension_mask_set);
+            return -1;
+        }
+        dimension_mask->mask[i] = result;
+        if (!dimension_mask->mask[i])
+        {
+            dimension_mask->masked_dimension_length--;
+        }
+    }
+
+    if (harp_product_filter(product, dimension_mask_set) != 0)
+    {
+        harp_dimension_mask_set_delete(dimension_mask_set);
+        return -1;
+    }
+
+    harp_dimension_mask_set_delete(dimension_mask_set);
+
+    return 0;
+}
+
 static int execute_point_filter(harp_product *product, harp_program *program)
 {
     harp_dimension_type dimension_type = harp_dimension_time;
@@ -1205,6 +1270,13 @@ int harp_product_execute_program(harp_product *product, harp_program *program)
                     return -1;
                 }
                 break;
+            case operation_index_comparison_filter:
+            case operation_index_membership_filter:
+                if (execute_index_filter(product, program) != 0)
+                {
+                    return -1;
+                }
+                break;
             case operation_point_distance_filter:
             case operation_point_in_area_filter:
                 if (execute_point_filter(product, program) != 0)
