@@ -1,33 +1,31 @@
-"""
-Copyright (C) 2015-2019 S[&]T, The Netherlands.
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are met:
-
-1. Redistributions of source code must retain the above copyright notice,
-   this list of conditions and the following disclaimer.
-
-2. Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in the
-   documentation and/or other materials provided with the distribution.
-
-3. Neither the name of the copyright holder nor the names of its
-   contributors may be used to endorse or promote products derived from
-   this software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
-LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-POSSIBILITY OF SUCH DAMAGE.
-"""
+# Copyright (C) 2015-2019 S[&]T, The Netherlands.
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+# 1. Redistributions of source code must retain the above copyright notice,
+# this list of conditions and the following disclaimer.
+#
+# 2. Redistributions in binary form must reproduce the above copyright
+# notice, this list of conditions and the following disclaimer in the
+# documentation and/or other materials provided with the distribution.
+#
+# 3. Neither the name of the copyright holder nor the names of its
+# contributors may be used to endorse or promote products derived from
+# this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
 
 from __future__ import print_function
 
@@ -348,13 +346,20 @@ def _get_c_library_filename():
     if _system() == "Windows":
         return "harp.dll"
 
-    import os.path
-    path = os.path.join(os.path.dirname(__file__), "../../..")
-
     if _system() == "Darwin":
-        return os.path.join(os.path.normpath(path), "libharp.dylib")
+        library_name = "libharp.dylib"
+    else:
+        library_name = "libharp.so"
 
-    return os.path.join(os.path.normpath(path), "libharp.so")
+    import os.path
+
+    # check for library file in the parent directory (for pyinstaller bundles)
+    library_path = os.path.normpath(os.path.join(os.path.dirname(__file__), "..", library_name))
+    if os.path.exists(library_path):
+        return library_path
+
+    # otherwise assume the library to be in the parent library directory
+    return os.path.normpath(os.path.join(os.path.dirname(__file__), "../../..", library_name))
 
 def _get_filesystem_encoding():
     """Return the encoding used by the filesystem."""
@@ -444,18 +449,6 @@ def _init():
             _lib.harp_type_string: "string"
         }
 
-def _all(predicate, sequence):
-    """Return True if the predicate evaluates to True for all elements in the
-    sequence, False otherwise.
-
-    Attributes:
-        predicate   --  Predicate to use; this should be a callable that takes a
-                        single argument and returns a bool.
-        sequence    --  Sequence to test.
-
-    """
-    return reduce(lambda x, y: x and predicate(y), sequence, True)
-
 def _dict_iteritems(dictionary):
     """Get an iterator or view on the items of the specified dictionary.
 
@@ -503,9 +496,9 @@ def _get_c_data_type(value):
         # the ndarray or scalar dtype.
         if numpy.issubdtype(value.dtype, numpy.object_):
             # NumPy object arrays are only used to contain variable length strings or byte strings.
-            if _all(lambda element: isinstance(element, str), value.flat):
+            if all(isinstance(x, str) for x in value.flat):
                 return _lib.harp_type_string
-            elif _all(lambda element: isinstance(element, bytes), value.flat):
+            elif all(isinstance(x, bytes) for x in value.flat):
                 return _lib.harp_type_string
             else:
                 raise UnsupportedTypeError("elements of a NumPy object array must be all str or all bytes")
@@ -1194,7 +1187,8 @@ def export_product(product, filename, file_format="netcdf", operations="", hdf5_
 
         if operations:
             # Apply operations to the product before export
-            _lib.harp_product_execute_operations(c_product_ptr[0], _encode_string(operations))
+            if _lib.harp_product_execute_operations(c_product_ptr[0], _encode_string(operations)) != 0:
+                raise CLibraryError()
 
         # Export the C product to a file.
         if file_format == 'hdf5':
